// GUI_italian.sce
// Generates on the Graphics Window (GW) a GUI that contains a  /
// sine plot (plot2d), a slider by which to adjust the angular  /
// frequency of the sine function, two radiobuttons that change /
// the style and color of the sine graph, and a pushbutton that /
// closes the GW

clear,clc;
// **** SUBROUTINES **** //
// Declaration of initial plot in GUI:
//------------------------------ ---------------
function initial_GUI()
    t = linspace(0,7,200);
    w = 5;
    // Initial angular frequency
    plot2d(t,sin(w.*t),rect = [0,-1.1,7,1.1]);  // Initial plot w=5 rad/s
    a = gca();
    a.axes_bounds = [0.2,0,.8,1];               // Frame dimensions & location
    xtitle("GUI DEMO WITH sin (wt)","Time [s]","Amplitude");
    a.font_size = 3;                            // Axes mark size
    a.x_label.font_size = 3;                    // x_label size
    a.y_label.font_size = 3;                    // y_label size
    a.title.font_size = 3;                      // Title size
endfunction

// Functions for changes wrt user actions:
//-------------------------------------------------------
function update_slider()                        // IF slider movement
    new_GUI_data();                             // GOTO new_GUI_data()
endfunction

function update_radio()                         // IF radiobutton click
    new_GUI_data();                             // GOTO new_GUI_data()
endfunction

// Redefine plot in GUI:
//------------------------------
function new_GUI_data()
    t = linspace(0,7,200)                       
    drawlater();                                // Delay changes
    
    a = gca();                                  // get axis handle
    if (a.children~=[]) then                    // IF frame contains graph...
        delete(a.children)                      // then delete graph
    end
    
    w = h_slider.value/10;                      // Slider range: 10 steps
    
    plot2d(t,sin(w.*t));                        
    if (h_radio1.value == 0) then               // Check status of style button
        a.children.children.polyline_style=1;   // Basic style: line
    else
        a.children.children.polyline_style=3;   // IF clicked: bars
    end
    
    if h_radio2.value==0 then                   // Check status of color button
        a.children.children.foreground=1;       // Basic color: black
    else
        a.children.children.foreground=2;       // IF clicked: blue
    end
    drawnow();
endfunction

// ***** MAIN *****

xdel();
funcprot(0);

// Define window size & position:
//--------------------------------------------
screen_size = get(0,"screensize_px");           // Find computer screen size
size_x = .7*screen_size(3);
// .7*screensize_px 3rd element
size_y = .7*screen_size(4);
// .7*screensize_px 4th element
h_graph = scf(0);
// Open Graphics Window
h_graph.figure_size = [size_x size_y];          // Define GW size
h_graph.figure_position =[size_x/5 size_y/6];  // Position GW in the...

// middle of the screen
// Open GUI with inital plot:
//-------------------------------------
initial_GUI();
// Add EXIT button:
//-------------------------
h_stop = uicontrol (h_graph,...
"style","pushbutton",...        // Declare pushbutton
"string","EXIT",...             // Pushbutton label
"fontsize",14,...
"backgroundColor",[1 0 0],...   // Red button RGB
"foregroundColor",[1 1 1],...   // White label RGB
"position",[85 size_y-210 50 50],...
"callback","xdel(0)");          // CLOSE GW if button pushed

// Add slider & label:
//--------------------------
h_slider= uicontrol( h_graph,...
"style","slider" ,...
"Min",0 ,...
"Max",100 ,...
"value",50 ,...
"position",[10 size_y-250 200 20] ,...
"callback", "update_slider();...
foo = strcat([''w = ''  string(h_slider.value/10) '' rad / s '']);...
h_text_slider.string = foo");

//h_text_slider.string = "foo";
slidelbl = strcat(["w = 5 rad/s"]);     // Define initial label
h_text_slider = uicontrol(h_graph,...   // Declare text
"style","text",...
"horizontalalignment","center",...      // Position in reserved field
"string",slidelbl,...                   // Add slider label
"fontsize",14,...
"backgroundColor",[1 1 1],...           // White background
"position",[10 size_y-310 180 20]);

// Field size & location
// Add radiobutton for graph style:
//---------------------------------------------
h_radio1 = uicontrol(h_graph,...        // Declare radiobutton"style","radiobutton",...
"style","radiobutton",...
"Min",0,...
"Max",1,...
"value",0,...                           // Initial button value
"backgroundColor",[1 1 1],...
"position",[10 size_y-350 20 20],...
"callback","update_radio()");           // GOTO to update_radio()

h_text_radio1 = uicontrol(h_graph,...
"style","text",...                      // Declare button text"horizontalalignment","left",...
"string","-Change graph style",...
"backgroundColor",[.8 .8 .8],...        // Gray background
"fontsize",14,...
"position",[40 size_y-350 140 25]);     // Field size & location

// Add radiobutton for graph color:
//----------------------------------------------
h_radio2 = uicontrol(h_graph,...
"style","radiobutton",...
"Min",0,...
"Max",1,...
"value",0,...
"backgroundColor",[1 1 1],...
"position",[10 size_y-380 20 20],...
"callback","update_radio()");

h_radio2_txt = uicontrol(h_graph,...
"style","text",...
"horizontalalignment","left",...
"string","-Change graph color",...
"backgroundColor",[.8 .8 .8],...
"fontsize",14,...
"position",[40 size_y-380 140 25]);
// **** END MAIN **** //
