// animation_pincon_m2.sce                                                      /
//------------------------------------------------------------------------------/
// The script plots the track of a blue polygon (rectangle)                     /
// with red border, as it turns around its axis while racing                    /
// counterclockwise in a circular loop on a black background.                   /
// The rectangle can be chaged to a trapetzoid or other shape                   /
// by changing element values in the matrix polygon. Changing                   /
// theta arguments in the matrix align gives different effects                  /
//------------------------------------------------------------------------------/
clear,clc,clf;
// Basic parameters:
//----------------------
steps = 100;                // Steps per circular loop
blength = 0.6;              // Basic length of polygon
width = 0.3;                // Basic width of polygon
radius = 0.6;               // Radius of circular loop
revolutions = 1;            // Number of loops to run

// Basic equations & definitions:
//------------------------------------
t = linspace(0,revolutions*2*%pi,steps)';
x_axis = radius*cos(t);      // x-axis of circular loop
y_axis = radius*sin(t);      // y-axis of circular loop
polygon = [-blength/2 blength/2 blength/2 -blength/2;...
-width/2 -width/2 width/2 width/2];
// Defines corners of polygon
// Set scale for isometric plot:
//---------------------------------
plot2d(%inf,%inf,frameflag=3, rect=[-1,-1,1,1], axesflag=0)
h = gca();
xtitle('Waltzing polygon')
h.background = 1;           // Set background to black

// Plot rectangle as it waltzes its loop:
//-------------------------------------------
turns = 3;                                          // Number of turns per loop
for i=1:steps
    sleep(100);
    theta = turns*t(i);                                 // Angle of polygon alignment
    align = [cos(theta) -sin(theta);...
    sin(theta) cos(theta)]*polygon;                     // Realigns polygon
    h.foreground = 2;
    // Set fill color to red
    xfpoly(align(1,:)+x_axis(i), align(2,:)+y_axis(i))  // Fills polygon with defined color
    h.foreground = 5;                                   // Change to blue for border
    h.thickness = 3;                                    // Set border thickness to 3
    xpoly(align(1,:)+x_axis(i), align(2,:)+y_axis(i),'lines',1) // Draws polygon border in defined color
end
