// bode_RC.sce                      /
// Bode diagram for an RC circuit   /
// (first-order low-pass filter)    /

clear,clc,clf;
R = 1e+3;                                           // Resistance in ohm
C = 1e-7;                                           // Capacitance in farad
freq = logspace(1,6,60);                            // Frequency range, logarithmic
G = 1 ./ (1 + %i*2*%pi*freq*R*C);                   // Transfer function
G_dB = 20*log10(abs(G));                            // Logarithmic scale
phase = ((atan(imag(G),real(G)))/(%pi))*180;        // Phase

subplot(211);                                       // Amplitude plot
plot2d(freq,G_dB,logflag='ln',style=5)              // Blue grid
xgrid(2)
xtitle('Amplitude','Frequency (Hz)','Gain (dB)')    // Phase plot
subplot(212)
plot2d(freq,phase,logflag='ln',style=2)
xgrid(3)                                            // Green grid
xtitle('Phase','Frequency (Hz)','Phase (deg)')
