// for-if-else.sce                                                  /
// -----------------------------------------------------------      /
// The script generates Gaussian noise around a fixed signal.       /
// Each sample ("signal") is sorted according to whether it         /
// is within, above or below default variance limits (+/-1). The    /
// result is reported verbally with strings and is also plotted
//

//------------------------------------------------------------------/
clear,clc,clf;
// Define variables:
// ------------------------
n = 500;                            // # of for...end loops
above = 0;                          // Signals above upper variance limit
below = 0;                          // Signals below lower variance limit
within = 0;                         // Signals within variance limits
ave = 3;                            // Mean (average)
x = [];                             // x axis vector

// Generate signal:
// ----------------------
dt = getdate();                     // Get date
rand('seed',(531+n)*dt(9)+dt(10)); // Initialize random generator
signal= ave + rand(1,n,'normal');  // Shifted Gaussian signal
// Sort signal:
// ----------------
for j = 1:1:n
    if signal(1,j) > ave+1 then     // Default variance = +/-1
        above = above + 1;          // Count signal > mean+var
    elseif signal(1,j) < ave-1      // Default variance = +/-1
        below = below +1;           // Count signal < mean-var
    else                            // If within variance limits
        within = within + 1;        // If within variance limits
    end
end

// Display result:
// --------------------
disp(['Result from generating', string(n), 'Gaussian distributed samples'])
disp(['(signals) with mean =' string(ave) 'and variance = 1:'])
disp([' -' string(within) ' samples were inside variance limits,'])
disp([' -' string(above) 'above upper variance limit, and'])
disp([' -' string(below) 'below lower limit'])
// Plot result:
// ---------------
x = [1:1:n];                        // Array for x axis
y1 = ave*ones(1,n);                 // Array for mean value
y2 = (ave+1)*ones(1,n);             // Array for upper variance limit
y3 = (ave-1)*ones(1,n);             // Array for lower variance limit
rect = [0,ave-4,n+1,ave+4];         // Set pLot window
plot2d(x,signal,2,"011"," ",rect)   // Plot samples
plot2d(x,y1,5,"000")                // Plot mean value
plot2d(x,y2,3,"000")                // Plot upper variance limit
plot2d(x,y3,3,"000")                // Plot upper variance limit
legend('signal','average','variance');
xtitle('GAUSSIAN RANDOM SAMPLES','Sample #','Sample value')
