// lotto2.sce
//----------------------------------------------------------------------/
// The script asks for the number of Lotto draws that we                /
// wish to do, using a separate dialog box. It then calls               /
// the local UDF lottodraw()) that generates a row of N                 /
// random Lotto numbers in the range [1,39]. It sorts the               /
// numbers into a vector by adding one (1) to the relevant              /
// vector element for each corresponding hit. The result                /
// is plotted after the entered number of draws.                        /

//--------------------------------------------------------------------- /
clear,clc,clf;
// (SUBROUTINE) function lottodraw():                                   /
//----------------------------------------------------------------------/
// The function draws N Lotto numbers [1,39], with                      /
// N being defined through the input argument in.                       /
// It delivers the drawn row to the calling script                      /
// command through the output argument out. The                         /
// randomness of the drawn numbers is improved by                       /
// first creating a seed using current date and                         /
// time (second, millisecond) information.                              /
function out=lottodraw(in)
dt=getdate();                           // Pick current date
rand('seed',1000*dt(9)+dt(10));         // Initialize random generator
out = floor(1+39*rand(1,in));           // Draw Lotto row (out variable)
while(length(unique(out))<in)           // If number repeats in row,
out = floor(1+39*rand(1,in));           // then a new row is drawn
end
endfunction
// (MAIN) Call subroutine, update histogram, plot:
//-------------------------------------------------------------------
M = evstr(x_dialog('Enter # of lotto draws ',''));  // Open dialog box

N = 7;                                   // Lotto numbers to draw
columns = zeros(1,39);                   // Initiate collecting vector
for k = 1:M
numbers = lottodraw(N);                  // Call to subroutine
columns(numbers)=columns(numbers)+1;     // Add 1 for drawn number
end
x = linspace(1,39,39);
// Define x axis
plot2d2(x,columns,style=2)               // Plot as step functions
xtitle('RESULT OF LOTTO DRAWS')          // Add title & labels
xlabel('Lotto numbers [1,39]')
ylabel('Hits')
