// robot_motion.sce                                         /

// Robot arm motion in two dimensions using a fifth-degree  /
// polynomial to control the motion. See Chapman, S.J.:     /
// "Matlab programming for Engineers," 2nd ed., for a       /
// detailed discussion. /
clear;clc,clf;

// Initial values, angles in degrees:
//---------------------------------------------
tf = 2;                                         // Finish time
theta10 = -19*%pi/180;                          // Theta 1 start position
theta1tf = 43*%pi/180;                          // Theta 1 final position
theta20 = 44*%pi/180;                           // Theta 2 start position
theta2tf = 151*%pi/180;                         // Theta 2 final position

// Equations for a coefficients (velocity
// constraints have been taken into account):
//------------------------------------------------------------
T = [tf^5 tf^4  tf^3 
    5*tf^4 4*tf^3 3*tf^2                            // Angular velocity
    20*tf^3 12*tf^2 6*tf ];                         // Angular acceleration
c = [ theta1tf - theta10; 0; 0 ];               // Theta 1 movement
a = T\c                                         // Coefficient vector a
disp(['Coefficients for theta1 motion:'])
disp([string(a')])

// Equations for b coefficients:
//---------------------------------------
d = [ theta2tf - theta20; 0; 0 ];               // Theta 2 movement
b= T\d                                          // Coefficient vector b
disp(['Coefficients for theta2 motion:'])
disp([string(b')])
// Equations of motion:
//------------------------------
L1 = 4;                                         // Length of upper arm [feet]
L2 = 3;                                         // Length of lower arm [feet]
t = linspace(0, 2, 401);                        // Computation steps
tq = [ t.^5; t.^4; t.^3 ];
theta1 = theta10 + a'*tq;                       // Base motor angular speed
theta2 = theta20 + b'*tq;                       // Elbow motor angular speed
x1 = L1*cos(theta1) + L2*cos(theta1 + theta2);  // x1 position
x2 = L1*sin(theta1) + L2*sin(theta1 + theta2);  // x2 position
// Plot path of hand, add labels & legend:
//------------------------------------------------------
plot(x1,x2),..
xlabel('x_1'),..
ylabel('x_2'),..
title('PATH OF A ROBOT HAND'),..
h1 = legend(['START: t=0s, (x_1,x_2) = (6.5,0); ..
STOP: t=2s, (x_1,x_2) = (0,2)'], 3)
